@@ -1,9 +1,9 @@
 from .link import Link
+from .linkpreview import LinkPreview
 from .grabber import LinkGrabber
-from .preview import LinkPreview
 from .compose import link_preview
 from .exceptions import LinkPreviewException
 
-__version__ = "0.2.2"
+__version__ = "0.6.5"
 
 __all__ = (Link, LinkGrabber, LinkPreview, link_preview, LinkPreviewException)
